library IEEE;
use IEEE.STD_LOGIC_1164.all;
use IEEE.Numeric_Std.all;

entity rom is
  port (
    clk25   : in  std_logic;
    charlin : in  unsigned (11 downto 0);
    dat_r   : out  std_logic_vector (7 downto 0)
 );
end entity rom;

architecture RTL of rom is

type rom_type is array (0 to 1023) of std_logic_vector(7 downto 0);
signal rom : rom_type :=(
x"00", x"60", x"10", x"14", x"64", x"07", x"84", x"07", 
x"F7", x"F7", x"F7", x"F7", x"F7", x"F7", x"F7", x"F7", 
x"00", x"24", x"34", x"22", x"22", x"71", x"01", x"80", 
x"00", x"74", x"84", x"72", x"82", x"71", x"01", x"80", 
x"00", x"F4", x"14", x"72", x"82", x"71", x"01", x"80", 
x"00", x"F4", x"84", x"42", x"22", x"11", x"01", x"80", 
x"00", x"C0", x"21", x"C0", x"00", x"00", x"00", x"00", 
x"00", x"00", x"80", x"80", x"F7", x"80", x"80", x"F7", 
x"00", x"00", x"01", x"02", x"F7", x"02", x"01", x"00", 
x"00", x"00", x"E3", x"14", x"14", x"E3", x"00", x"00", 
x"00", x"00", x"80", x"00", x"F7", x"00", x"80", x"00", 
x"00", x"80", x"80", x"80", x"94", x"A2", x"C1", x"80", 
x"F7", x"00", x"00", x"00", x"00", x"00", x"00", x"00", 
x"00", x"F7", x"00", x"00", x"00", x"00", x"00", x"00", 
x"00", x"00", x"F7", x"00", x"00", x"00", x"00", x"00", 
x"00", x"00", x"00", x"F7", x"00", x"00", x"00", x"00", 
x"00", x"00", x"00", x"00", x"F7", x"00", x"00", x"00", 
x"00", x"00", x"00", x"00", x"00", x"F7", x"00", x"00", 
x"00", x"00", x"00", x"00", x"00", x"00", x"F7", x"00", 
x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"F7", 
x"00", x"00", x"00", x"60", x"90", x"90", x"90", x"60", 
x"00", x"00", x"00", x"20", x"30", x"20", x"20", x"70", 
x"00", x"00", x"00", x"70", x"80", x"60", x"10", x"F0", 
x"00", x"00", x"00", x"70", x"80", x"60", x"80", x"70", 
x"00", x"00", x"00", x"40", x"60", x"50", x"F0", x"40", 
x"00", x"00", x"00", x"F0", x"10", x"70", x"80", x"70", 
x"00", x"00", x"00", x"E0", x"10", x"70", x"90", x"60", 
x"00", x"00", x"00", x"F0", x"80", x"40", x"20", x"10", 
x"00", x"00", x"00", x"60", x"90", x"60", x"90", x"60", 
x"00", x"00", x"00", x"60", x"90", x"E0", x"80", x"70", 
x"00", x"E7", x"F2", x"F2", x"E2", x"82", x"82", x"82", 
x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00", 
x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00", 
x"00", x"80", x"80", x"80", x"80", x"80", x"00", x"80", 
x"00", x"41", x"41", x"41", x"00", x"00", x"00", x"00", 
x"00", x"41", x"41", x"F7", x"41", x"F7", x"41", x"41", 
x"00", x"14", x"C1", x"22", x"22", x"22", x"C1", x"14", 
x"00", x"34", x"32", x"01", x"80", x"40", x"26", x"16", 
x"00", x"C1", x"22", x"41", x"80", x"45", x"22", x"C5", 
x"00", x"03", x"01", x"80", x"00", x"00", x"00", x"00", 
x"00", x"02", x"01", x"80", x"80", x"80", x"01", x"02", 
x"00", x"20", x"40", x"80", x"80", x"80", x"40", x"20", 
x"00", x"80", x"94", x"A2", x"C1", x"A2", x"94", x"80", 
x"00", x"00", x"80", x"80", x"F7", x"80", x"80", x"00", 
x"00", x"00", x"00", x"00", x"00", x"03", x"01", x"80", 
x"00", x"00", x"00", x"00", x"F7", x"00", x"00", x"00", 
x"00", x"00", x"00", x"00", x"00", x"00", x"81", x"81", 
x"00", x"04", x"02", x"01", x"80", x"40", x"20", x"10", 
x"00", x"C1", x"22", x"15", x"94", x"54", x"22", x"C1", 
x"00", x"80", x"C0", x"A0", x"80", x"80", x"80", x"E3", 
x"00", x"E1", x"12", x"04", x"83", x"60", x"10", x"F7", 
x"00", x"F7", x"02", x"01", x"03", x"04", x"14", x"E3", 
x"00", x"01", x"81", x"41", x"21", x"F7", x"01", x"01", 
x"00", x"F7", x"10", x"D3", x"34", x"04", x"14", x"E3", 
x"00", x"C3", x"24", x"10", x"D3", x"34", x"24", x"C3", 
x"00", x"F7", x"04", x"02", x"01", x"80", x"40", x"20", 
x"00", x"E3", x"14", x"14", x"E3", x"14", x"14", x"E3", 
x"00", x"E1", x"12", x"16", x"E5", x"04", x"12", x"E1", 
x"00", x"00", x"81", x"81", x"00", x"00", x"81", x"81", 
x"00", x"00", x"81", x"81", x"00", x"81", x"01", x"80", 
x"00", x"02", x"01", x"80", x"40", x"80", x"01", x"02", 
x"00", x"00", x"00", x"F7", x"00", x"F7", x"00", x"00", 
x"00", x"20", x"40", x"80", x"01", x"80", x"40", x"20", 
x"00", x"E3", x"14", x"04", x"83", x"80", x"00", x"80", 
x"00", x"E3", x"14", x"17", x"94", x"93", x"10", x"E3", 
x"00", x"80", x"41", x"22", x"14", x"F7", x"14", x"14", 
x"00", x"F3", x"24", x"24", x"E3", x"24", x"24", x"F3", 
x"00", x"C3", x"24", x"10", x"10", x"10", x"24", x"C3", 
x"00", x"F3", x"24", x"24", x"24", x"24", x"24", x"F3", 
x"00", x"F7", x"10", x"10", x"F1", x"10", x"10", x"F7", 
x"00", x"F7", x"10", x"10", x"F1", x"10", x"10", x"10", 
x"00", x"E3", x"14", x"10", x"17", x"14", x"14", x"E3", 
x"00", x"14", x"14", x"14", x"F7", x"14", x"14", x"14", 
x"00", x"E3", x"80", x"80", x"80", x"80", x"80", x"E3", 
x"00", x"04", x"04", x"04", x"04", x"04", x"14", x"E3", 
x"00", x"14", x"13", x"D0", x"30", x"D0", x"13", x"14", 
x"00", x"10", x"10", x"10", x"10", x"10", x"10", x"F7", 
x"00", x"14", x"36", x"55", x"94", x"14", x"14", x"14", 
x"00", x"14", x"34", x"54", x"94", x"15", x"16", x"14", 
x"00", x"E3", x"14", x"14", x"14", x"14", x"14", x"E3", 
x"00", x"F3", x"14", x"14", x"F3", x"10", x"10", x"10", 
x"00", x"E3", x"14", x"14", x"14", x"15", x"12", x"E5", 
x"00", x"F3", x"14", x"14", x"F3", x"11", x"12", x"14", 
x"00", x"E3", x"14", x"10", x"E3", x"04", x"14", x"E3", 
x"00", x"F7", x"80", x"80", x"80", x"80", x"80", x"80", 
x"00", x"14", x"14", x"14", x"14", x"14", x"14", x"E3", 
x"00", x"14", x"14", x"22", x"22", x"41", x"41", x"80", 
x"00", x"14", x"14", x"14", x"94", x"94", x"55", x"22", 
x"00", x"14", x"22", x"41", x"80", x"41", x"22", x"14", 
x"00", x"14", x"22", x"41", x"80", x"80", x"80", x"80", 
x"00", x"F7", x"02", x"01", x"80", x"40", x"20", x"F7", 
x"00", x"E3", x"60", x"60", x"60", x"60", x"60", x"E3", 
x"00", x"10", x"20", x"40", x"80", x"01", x"02", x"04", 
x"00", x"E3", x"03", x"03", x"03", x"03", x"03", x"E3", 
x"00", x"80", x"41", x"22", x"00", x"00", x"00", x"00", 
x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"F7", 
x"00", x"C0", x"80", x"01", x"00", x"00", x"00", x"00", 
x"00", x"00", x"00", x"E3", x"04", x"E7", x"14", x"E7", 
x"00", x"10", x"10", x"D3", x"34", x"14", x"34", x"D3", 
x"00", x"00", x"00", x"E3", x"14", x"10", x"10", x"E7", 
x"00", x"04", x"04", x"E5", x"16", x"14", x"16", x"E5", 
x"00", x"00", x"00", x"E1", x"12", x"F7", x"10", x"E3", 
x"00", x"03", x"84", x"C1", x"80", x"80", x"80", x"80", 
x"00", x"00", x"00", x"C5", x"22", x"C3", x"12", x"E1", 
x"00", x"10", x"10", x"F3", x"14", x"14", x"14", x"14", 
x"00", x"80", x"00", x"C0", x"80", x"80", x"80", x"E3", 
x"00", x"04", x"00", x"04", x"04", x"04", x"12", x"E1", 
x"00", x"10", x"10", x"11", x"90", x"50", x"11", x"14", 
x"00", x"C0", x"80", x"80", x"80", x"80", x"80", x"C1", 
x"00", x"00", x"00", x"73", x"94", x"94", x"94", x"94", 
x"00", x"00", x"00", x"D3", x"34", x"14", x"14", x"14", 
x"00", x"00", x"00", x"E3", x"14", x"14", x"14", x"E3", 
x"00", x"00", x"00", x"D3", x"34", x"F3", x"10", x"10", 
x"00", x"00", x"00", x"E5", x"16", x"E7", x"04", x"04", 
x"00", x"00", x"00", x"93", x"64", x"20", x"20", x"20", 
x"00", x"00", x"00", x"E3", x"10", x"E3", x"04", x"F3", 
x"00", x"40", x"40", x"E0", x"40", x"40", x"42", x"81", 
x"00", x"00", x"00", x"12", x"12", x"12", x"12", x"E5", 
x"00", x"00", x"00", x"14", x"14", x"22", x"41", x"80", 
x"00", x"00", x"00", x"14", x"14", x"94", x"55", x"22", 
x"00", x"00", x"00", x"12", x"21", x"C0", x"21", x"12", 
x"00", x"00", x"00", x"14", x"22", x"41", x"80", x"60", 
x"00", x"00", x"00", x"F7", x"02", x"C1", x"20", x"F7", 
x"00", x"07", x"80", x"80", x"60", x"80", x"80", x"07", 
x"00", x"80", x"80", x"80", x"80", x"80", x"80", x"80", 
x"00", x"70", x"80", x"80", x"03", x"80", x"80", x"70", 
x"00", x"44", x"A2", x"11", x"00", x"00", x"00", x"00", 
x"00", x"00", x"00", x"00", x"00", x"00", x"00", x"00");

begin

process(clk25)
begin
  if rising_edge(clk25) then
    dat_r <= rom((to_integer(charlin)));
  end if;  
end process;
end architecture RTL;