library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.NUMERIC_STD.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity vga_text is
port(
  clk48     : in std_logic;
  hs_out    : out std_logic;
  vs_out    : out std_logic;
  
  red_out   : OUT STD_LOGIC_VECTOR(4 downto 0);
  green_out : OUT STD_LOGIC_VECTOR(5 downto 0);
  blue_out  : OUT STD_LOGIC_VECTOR(4 downto 0)
  ); 
end vga_text;

architecture behavioral of vga_text is

signal offs     : unsigned (6 downto 0);
signal counterx : unsigned (9 downto 0);
signal countery : unsigned (9 downto 0);
signal basis    : unsigned (11 downto 0);
signal charlin  : unsigned (11 downto 0);
signal rd_addr  : unsigned (11 downto 0);
signal wr_addr  : unsigned (11 downto 0);

signal dat_r     : std_logic_vector (7 downto 0);
signal char    : std_logic_vector (7 downto 0);
signal dat_w   : std_logic_vector (7 downto 0);

signal counterxmaxed : std_logic;
signal counterymaxed : std_logic;
signal h_enable      : std_logic;
signal v_enable      : std_logic;
signal vid_enable    : std_logic;
signal pixel         : std_logic;
signal clk25         : std_logic;
signal we            : std_logic;

component clkpll is
    port (
      inclk0    : in std_logic;
      c0        : out std_logic
	  );
end component;

component ram port(
  clk25   : in  std_logic;
  we      : in  std_logic;
  wr_addr : in  unsigned (11 downto 0);
  rd_addr : in  unsigned (11 downto 0);
  dat_w   : in  std_logic_vector (7 downto 0);
  char    : out std_logic_vector (7 downto 0)
  );
end component;

component rom port(
  clk25   : in  std_logic;
  charlin : in  unsigned (11 downto 0);
  dat_r   : out std_logic_vector (7 downto 0)
  );
end component;

begin
io1 : ram  port map(
 clk25   => clk25,
 we      => we,
 rd_addr => rd_addr,
 wr_addr => wr_addr,
 char    => char,
 dat_w   => dat_w
);

io2 : rom  port map(
  clk25   => clk25,
  charlin => charlin,
  dat_r   => dat_r
);

clkpll_inst : clkpll port map (
  inclk0 => clk48 ,
  c0     => clk25
  );

process(clk25)
begin
  if rising_edge(clk25) then
    if counterxmaxed ='1' then
      counterx <= to_unsigned(0, counterx'length);
    else
      counterx <= counterx + 1; 
      if dat_r(to_integer(unsigned(counterx(2 downto 0)))) = '0' then
        pixel<='0';
      else
        pixel<='1';
      end if;       
    end if;
    
    if counterxmaxed ='1' then
      if counterymaxed ='1' then 
        countery <=  to_unsigned(0, countery'length);
      else  
        countery<= countery + 1;      
      end if;  
    end if ; 
    
    if counterx (2 downto 0)="000" then
      if counterx =0 and  countery =0 then
        basis <=to_unsigned(0, basis'length);
      elsif counterx =0 and countery(3 downto 0) =0 then 
        basis<= basis + 80; 
      end if;        
    end if;    
  
    offs <= counterx(9 downto 3);
    rd_addr <= basis + offs;
  end if;  
end process;

process(clk48)
begin
  if rising_edge(clk48) then
    if vid_enable ='1' and pixel='1' then
      red_out  <="11111";
      green_out<="111111";
      blue_out <="11111";
    else
      red_out  <="00000";
      green_out<="000000";
      blue_out <="00000";    
    end if;
    
    charlin <= unsigned('0' & char & std_logic_vector(countery(3 downto 1)));
  end if;  
end process;

counterxmaxed <='1' when  counterx = 800 else '0';
counterymaxed <='1' when  countery = 525 else '0';

hs_out <='1' when  counterx < 658 or counterx > 751 else '0';
vs_out <='1' when  countery < 489 or countery > 491 else '0';

h_enable   <= '1' when  counterx > 4 and counterx < 645 else '0';
v_enable   <= '1' when  countery < 480 else '0'; 
vid_enable <= '1' when h_enable = '1' and v_enable = '1' else '0';
 
end behavioral;